@@ -2,6 +2,25 @@
 import os
 # import yaml
 
+class POOLTYPE:
+    SIMPLE = "simple"
+    STEADY = "steady"
+
+    @classmethod
+    def to_list(cls):
+        return [cls.SIMPLE, cls.STEADY]
+
+class Config(object):
+    debug = True
+    ptype = 'simple'
+    _instance = None
+    def __new__(cls, *args, **kw):
+        if cls._instance is None:
+            cls._instance = object.__new__(cls, *args, **kw)
+        return cls._instance
+    def __init__(self):
+        pass
+
 SESSION_CONF = {}
 MSGPASS_CONF = {}
 ETCD_CONF = {}
