@@ -83,7 +83,7 @@ Copyright, credits and license:
 
 * Contributed as supplement for Webware for Python and PyGreSQL
   by Christoph Zwerschke in September 2005
-* Allowing creator functions as first parameter as in SQLAlchemy
+* Allowing engine functions as first parameter as in SQLAlchemy
   suggested by Ezio Vernacotola in December 2006
 
 Licensed under the MIT license.
@@ -104,11 +104,11 @@ class InvalidCursor(SteadyDBError):
 
 
 def connect(
-        creator, maxusage=None, setsession=None,
+        engine, maxusage=None, setsession=None,
         failures=None, ping=1, closeable=True, *args, **kwargs):
     """A tough version of the connection constructor of a DB-API 2 module.
 
-    creator: either an arbitrary function returning new DB-API 2 compliant
+    engine: either an arbitrary function returning new DB-API 2 compliant
         connection objects or a DB-API 2 compliant database module
     maxusage: maximum usage limit for the underlying DB-API 2 connection
         (number of database operations, 0 or None means unlimited usage)
@@ -125,11 +125,11 @@ def connect(
         7 = always, and all other bit combinations of these values)
     closeable: if this is set to false, then closing the connection will
         be silently ignored, but by default the connection can be closed
-    args, kwargs: the parameters that shall be passed to the creator
+    args, kwargs: the parameters that shall be passed to the engine
         function or the connection constructor of the DB-API 2 module
     """
     return SteadyDBConnection(
-        creator, maxusage, setsession,
+        engine, maxusage, setsession,
         failures, ping, closeable, *args, **kwargs)
 
 
@@ -137,37 +137,37 @@ class SteadyDBConnection(SimpleDBConnection):
     """A "tough" version of DB-API 2 connections."""
 
     def __init__(
-            self, creator, maxusage=None, setsession=None,
+            self, engine, maxusage=None, setsession=None,
             failures=None, ping=1, closeable=True, *args, **kwargs):
         """Create a "tough" DB-API 2 connection."""
         # basic initialization to make finalizer work
-        self._con = None
+        self._conn = None
         self._closed = True
         # proper initialization of the connection
         try:
-            self._creator = creator.connect
-            self._dbapi = creator
+            self._engine = engine.connect
+            self._dbapi = engine
         except AttributeError:
-            # try finding the DB-API 2 module via the connection creator
-            self._creator = creator
+            # try finding the DB-API 2 module via the connection engine
+            self._engine = engine
             try:
-                self._dbapi = creator.dbapi
+                self._dbapi = engine.dbapi
             except AttributeError:
                 try:
-                    self._dbapi = sys.modules[creator.__module__]
-                    if self._dbapi.connect != creator:
+                    self._dbapi = sys.modules[engine.__module__]
+                    if self._dbapi.connect != engine:
                         raise AttributeError
                 except (AttributeError, KeyError):
                     self._dbapi = None
         try:
-            self._threadsafety = creator.threadsafety
+            self._threadsafety = engine.threadsafety
         except AttributeError:
             try:
                 self._threadsafety = self._dbapi.threadsafety
             except AttributeError:
                 self._threadsafety = None
-        if not callable(self._creator):
-            raise TypeError("%r is not a connection provider." % (creator,))
+        if not callable(self._engine):
+            raise TypeError("%r is not a connection provider." % (engine,))
         if maxusage is None:
             maxusage = 0
         if not isinstance(maxusage, baseint):
@@ -199,16 +199,16 @@ class SteadyDBConnection(SimpleDBConnection):
             self.rollback()
 
     def _create(self):
-        """Create a new connection using the creator function."""
-        con = self._creator(*self._args, **self._kwargs)
+        """Create a new connection using the engine function."""
+        conn = self._engine(*self._args, **self._kwargs)
         try:
             try:
-                if self._dbapi.connect != self._creator:
+                if self._dbapi.connect != self._engine:
                     raise AttributeError
             except AttributeError:
                 # try finding the DB-API 2 module via the connection itself
                 try:
-                    mod = con.__module__
+                    mod = conn.__module__
                 except AttributeError:
                     mod = None
                 while mod:
@@ -227,7 +227,7 @@ class SteadyDBConnection(SimpleDBConnection):
                         mod = mod[:i]
                 else:
                     try:
-                        mod = con.OperationalError.__module__
+                        mod = conn.OperationalError.__module__
                     except AttributeError:
                         mod = None
                     while mod:
@@ -251,7 +251,7 @@ class SteadyDBConnection(SimpleDBConnection):
                     self._threadsafety = self._dbapi.threadsafety
                 except AttributeError:
                     try:
-                        self._threadsafety = con.threadsafety
+                        self._threadsafety = conn.threadsafety
                     except AttributeError:
                         pass
             if self._failures is None:
@@ -262,44 +262,44 @@ class SteadyDBConnection(SimpleDBConnection):
                 except AttributeError:
                     try:
                         self._failures = (
-                            self._creator.OperationalError,
-                            self._creator.InternalError)
+                            self._engine.OperationalError,
+                            self._engine.InternalError)
                     except AttributeError:
                         try:
                             self._failures = (
-                                con.OperationalError, con.InternalError)
+                                conn.OperationalError, conn.InternalError)
                         except AttributeError:
                             raise AttributeError(
                                 "Could not determine failure exceptions"
-                                " (please set failures or creator.dbapi).")
+                                " (please set failures or engine.dbapi).")
             if isinstance(self._failures, tuple):
                 self._failure = self._failures[0]
             else:
                 self._failure = self._failures
-            self._setsession(con)
+            self._setsession(conn)
         except Exception as error:
             # the database module could not be determined
             # or the session could not be prepared
             try:  # close the connection first
-                con.close()
+                conn.close()
             except Exception:
                 pass
             raise error  # re-raise the original error again
-        return con
+        return conn
 
-    def _setsession(self, con=None):
+    def _setsession(self, conn=None):
         """Execute the SQL commands for session preparation."""
-        if con is None:
-            con = self._con
+        if conn is None:
+            conn = self._conn
         if self._setsession_sql:
-            cursor = con.cursor()
+            cursor = conn.cursor()
             for sql in self._setsession_sql:
                 cursor.execute(sql)
             cursor.close()
 
-    def _store(self, con):
+    def _store(self, conn):
         """Store a database connection for subsequent use."""
-        self._con = con
+        self._conn = conn
         self._transaction = False
         self._closed = False
         self._usage = 0
@@ -312,7 +312,7 @@ class SteadyDBConnection(SimpleDBConnection):
         """
         if not self._closed:
             try:
-                self._con.close()
+                self._conn.close()
             except Exception:
                 pass
             self._transaction = False
@@ -339,9 +339,9 @@ class SteadyDBConnection(SimpleDBConnection):
         if ping & self._ping:
             try:  # if possible, ping the connection
                 try:  # pass a reconnect=False flag if this is supported
-                    alive = self._con.ping(False)
+                    alive = self._conn.ping(False)
                 except TypeError:  # the reconnect flag is not supported
-                    alive = self._con.ping()
+                    alive = self._conn.ping()
             except (AttributeError, IndexError, TypeError, ValueError):
                 self._ping = 0  # ping() is not available
                 alive = None
@@ -355,12 +355,12 @@ class SteadyDBConnection(SimpleDBConnection):
                     reconnect = False
             if reconnect and not self._transaction:
                 try:  # try to reopen the connection
-                    con = self._create()
+                    conn = self._create()
                 except Exception:
                     pass
                 else:
                     self._close()
-                    self._store(con)
+                    self._store(conn)
                     alive = True
             return alive
 
@@ -369,7 +369,7 @@ class SteadyDBConnection(SimpleDBConnection):
         if self._dbapi is None:
             raise AttributeError(
                 "Could not determine DB-API 2 module"
-                " (please set creator.dbapi).")
+                " (please set engine.dbapi).")
         return self._dbapi
 
     def threadsafety(self):
@@ -378,7 +378,7 @@ class SteadyDBConnection(SimpleDBConnection):
             if self._dbapi is None:
                 raise AttributeError(
                     "Could not determine threadsafety"
-                    " (please set creator.dbapi or creator.threadsafety).")
+                    " (please set engine.dbapi or engine.threadsafety).")
             return 0
         return self._threadsafety
 
@@ -408,7 +408,7 @@ class SteadyDBConnection(SimpleDBConnection):
         """
         self._transaction = True
         try:
-            begin = self._con.begin
+            begin = self._conn.begin
         except AttributeError:
             pass
         else:
@@ -418,30 +418,30 @@ class SteadyDBConnection(SimpleDBConnection):
         """Commit any pending transaction."""
         self._transaction = False
         try:
-            self._con.commit()
+            self._conn.commit()
         except self._failures as error:  # cannot commit
             try:  # try to reopen the connection
-                con = self._create()
+                conn = self._create()
             except Exception:
                 pass
             else:
                 self._close()
-                self._store(con)
+                self._store(conn)
             raise error  # re-raise the original error
 
     def rollback(self):
         """Rollback pending transaction."""
         self._transaction = False
         try:
-            self._con.rollback()
+            self._conn.rollback()
         except self._failures as error:  # cannot rollback
             try:  # try to reopen the connection
-                con = self._create()
+                conn = self._create()
             except Exception:
                 pass
             else:
                 self._close()
-                self._store(con)
+                self._store(conn)
             raise error  # re-raise the original error
 
     def cancel(self):
@@ -451,7 +451,7 @@ class SteadyDBConnection(SimpleDBConnection):
         """
         self._transaction = False
         try:
-            cancel = self._con.cancel
+            cancel = self._conn.cancel
         except AttributeError:
             pass
         else:
@@ -459,7 +459,7 @@ class SteadyDBConnection(SimpleDBConnection):
 
     def ping(self, *args, **kwargs):
         """Ping connection."""
-        return self._con.ping(*args, **kwargs)
+        return self._conn.ping(*args, **kwargs)
 
     def _cursor(self, *args, **kwargs):
         """A "tough" version of the method cursor()."""
@@ -473,25 +473,25 @@ class SteadyDBConnection(SimpleDBConnection):
             if (self._maxusage and self._usage >= self._maxusage and
                     not transaction):
                 raise self._failure
-            cursor = self._con.cursor(*args, **kwargs)  # try to get a cursor
+            cursor = self._conn.cursor(*args, **kwargs)  # try to get a cursor
         except self._failures as error:  # error in getting cursor
             try:  # try to reopen the connection
-                con = self._create()
+                conn = self._create()
             except Exception:
                 pass
             else:
                 try:  # and try one more time to get a cursor
-                    cursor = con.cursor(*args, **kwargs)
+                    cursor = conn.cursor(*args, **kwargs)
                 except Exception:
                     pass
                 else:
                     self._close()
-                    self._store(con)
+                    self._store(conn)
                     if transaction:
                         raise error  # re-raise the original error again
                     return cursor
                 try:
-                    con.close()
+                    conn.close()
                 except Exception:
                     pass
             if transaction:
@@ -514,19 +514,19 @@ class SteadyDBConnection(SimpleDBConnection):
 class SteadyDBCursor:
     """A "tough" version of DB-API 2 cursors."""
 
-    def __init__(self, con, *args, **kwargs):
+    def __init__(self, conn, *args, **kwargs):
         """Create a "tough" DB-API 2 cursor."""
         # basic initialization to make finalizer work
         self._cursor = None
         self._closed = True
         # proper initialization of the cursor
-        self._con = con
+        self._conn = conn
         self._args, self._kwargs = args, kwargs
         self._clearsizes()
         try:
-            self._cursor = con._cursor(*args, **kwargs)
+            self._cursor = conn._cursor(*args, **kwargs)
         except AttributeError:
-            raise TypeError("%r is not a SteadyDBConnection." % (con,))
+            raise TypeError("%r is not a SteadyDBConnection." % (conn,))
         self._closed = False
 
     def __enter__(self):
@@ -578,25 +578,25 @@ class SteadyDBCursor:
         """Return a "tough" version of the given cursor method."""
         def tough_method(*args, **kwargs):
             execute = name.startswith('execute')
-            con = self._con
-            transaction = con._transaction
+            conn = self._conn
+            transaction = conn._transaction
             if not transaction:
-                con._ping_check(4)
+                conn._ping_check(4)
             try:
                 # check whether the connection has been used too often
-                if (con._maxusage and con._usage >= con._maxusage and
+                if (conn._maxusage and conn._usage >= conn._maxusage and
                         not transaction):
-                    raise con._failure
+                    raise conn._failure
                 if execute:
                     self._setsizes()
                 method = getattr(self._cursor, name)
                 result = method(*args, **kwargs)  # try to execute
                 if execute:
                     self._clearsizes()
-            except con._failures as error:  # execution error
+            except conn._failures as error:  # execution error
                 if not transaction:
                     try:
-                        cursor2 = con._cursor(
+                        cursor2 = conn._cursor(
                             *self._args, **self._kwargs)  # open new cursor
                     except Exception:
                         pass
@@ -613,27 +613,27 @@ class SteadyDBCursor:
                         else:
                             self.close()
                             self._cursor = cursor2
-                            con._usage += 1
+                            conn._usage += 1
                             return result
                         try:
                             cursor2.close()
                         except Exception:
                             pass
                 try:  # try to reopen the connection
-                    con2 = con._create()
+                    conn2 = conn._create()
                 except Exception:
                     pass
                 else:
                     try:
-                        cursor2 = con2.cursor(
+                        cursor2 = conn2.cursor(
                             *self._args, **self._kwargs)  # open new cursor
                     except Exception:
                         pass
                     else:
                         if transaction:
                             self.close()
-                            con._close()
-                            con._store(con2)
+                            conn._close()
+                            conn._store(conn2)
                             self._cursor = cursor2
                             raise error  # raise the original error again
                         error2 = None
@@ -654,10 +654,10 @@ class SteadyDBCursor:
                             use2 = True
                         if use2:
                             self.close()
-                            con._close()
-                            con._store(con2)
+                            conn._close()
+                            conn._store(conn2)
                             self._cursor = cursor2
-                            con._usage += 1
+                            conn._usage += 1
                             if error2:
                                 raise error2  # raise the other error
                             return result
@@ -666,14 +666,14 @@ class SteadyDBCursor:
                         except Exception:
                             pass
                     try:
-                        con2.close()
+                        conn2.close()
                     except Exception:
                         pass
                 if transaction:
                     self._transaction = False
                 raise error  # re-raise the original error again
             else:
-                con._usage += 1
+                conn._usage += 1
                 return result
         return tough_method
 
